==> koffice-trinity_3.5.13.2.orig.tar.xz: koffice-trinity-3.5.13.2/kformula/kformula_view.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Andrea Rizzi <rizzi@kde.org>
	              Ulrich Kuettler <ulrich.kuettler@mailbox.tu-dresden.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __kformula_view_h__
#define __kformula_view_h__

class KAction;
class KFormulaDoc;
class KFormulaPartView;
class KFormulaWidget;
class KSelectAction;
class TQPaintEvent;
class TQScrollView;
class DCOPObject;

namespace KFormula {
    class View;
}

#include <KoView.h>
#include <tqptrlist.h>
#include <tqstringlist.h>

/**
 * The parts view.
 */
class KFormulaPartView : public KoView
{
    Q_OBJECT
  TQ_OBJECT

public:
    KFormulaPartView(KFormulaDoc* _doc, TQWidget* _parent=0, const char* _name=0);
    virtual ~KFormulaPartView();
    virtual DCOPObject* dcopObject();

    virtual void setupPrinter( KPrinter &printer );
    virtual void print( KPrinter &printer );

    KFormulaDoc* document() const { return m_pDoc; }

    const KFormula::View* formulaView() const;
    KFormula::View* formulaView();

    TQStringList readFormulaString( TQString text );

protected:

    virtual void resizeEvent(TQResizeEvent* _ev);
    virtual void focusInEvent(TQFocusEvent*);

    virtual void updateReadWrite(bool);

protected slots:

    void configure();
    void cursorChanged(bool visible, bool selecting);

    void formulaString();

    void sizeSelected( int );

    void slotShowTipOnStart();
    void slotShowTip();

private:

    /**
     * Enables the actions that modify the formula.
     */
    void setEnabled(bool enabled);

    KFormulaDoc *m_pDoc;
    KFormulaWidget* formulaWidget;
    TQScrollView* scrollview;

    KAction* cutAction;
    KAction* copyAction;
    KAction* pasteAction;

    KAction* addBracketAction;
    KAction* addFractionAction;
    KAction* addRootAction;
    KAction* addSumAction;
    KAction* addProductAction;
    KAction* addIntegralAction;
    KAction* addMatrixAction;
    KAction* addUpperLeftAction;
    KAction* addLowerLeftAction;
    KAction* addUpperRightAction;
    KAction* addLowerRightAction;
    KAction* addGenericUpperAction;
    KAction* addGenericLowerAction;
    KAction* removeEnclosingAction;

    KAction* formulaStringAction;

    static bool first_window;

    DCOPObject *m_dcop;
};

#endif

==> koffice-trinity-14.0.13.tar.xz: koffice-trinity-14.0.13/kformula/kformula_view.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Andrea Rizzi <rizzi@kde.org>
	              Ulrich Kuettler <ulrich.kuettler@mailbox.tu-dresden.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __kformula_view_h__
#define __kformula_view_h__

class TDEAction;
class KFormulaDoc;
class KFormulaPartView;
class KFormulaWidget;
class TDESelectAction;
class TQPaintEvent;
class TQScrollView;
class DCOPObject;

namespace KFormula {
    class View;
}

#include <KoView.h>
#include <tqptrlist.h>
#include <tqstringlist.h>

/**
 * The parts view.
 */
class KFormulaPartView : public KoView
{
    Q_OBJECT
  

public:
    KFormulaPartView(KFormulaDoc* _doc, TQWidget* _parent=0, const char* _name=0);
    virtual ~KFormulaPartView();
    virtual DCOPObject* dcopObject();

    virtual void setupPrinter( KPrinter &printer );
    virtual void print( KPrinter &printer );

    KFormulaDoc* document() const { return m_pDoc; }

    const KFormula::View* formulaView() const;
    KFormula::View* formulaView();

    TQStringList readFormulaString( TQString text );

protected:

    virtual void resizeEvent(TQResizeEvent* _ev);
    virtual void focusInEvent(TQFocusEvent*);

    virtual void updateReadWrite(bool);

protected slots:

    void configure();
    void cursorChanged(bool visible, bool selecting);

    void formulaString();

    void sizeSelected( int );

    void slotShowTipOnStart();
    void slotShowTip();

private:

    /**
     * Enables the actions that modify the formula.
     */
    void setEnabled(bool enabled);

    KFormulaDoc *m_pDoc;
    KFormulaWidget* formulaWidget;
    TQScrollView* scrollview;

    TDEAction* cutAction;
    TDEAction* copyAction;
    TDEAction* pasteAction;

    TDEAction* addBracketAction;
    TDEAction* addFractionAction;
    TDEAction* addRootAction;
    TDEAction* addSumAction;
    TDEAction* addProductAction;
    TDEAction* addIntegralAction;
    TDEAction* addMatrixAction;
    TDEAction* addUpperLeftAction;
    TDEAction* addLowerLeftAction;
    TDEAction* addUpperRightAction;
    TDEAction* addLowerRightAction;
    TDEAction* addGenericUpperAction;
    TDEAction* addGenericLowerAction;
    TDEAction* removeEnclosingAction;

    TDEAction* formulaStringAction;

    static bool first_window;

    DCOPObject *m_dcop;
};

#endif
